@@ -1,108 +1,28 @@
 # -*- coding: utf-8 -*-
 
-class Variable():
-    def __init__(self, value):
-        self.__value = value
-        self.__compute = None
-        self.__method = None
-
-    def __repr__(self):
-        return repr(self.__value)
-
-    def __str__(self):
-        return str(self.__value)
-
-    def __get__(self, instance, owner):
-        return self
-
-    def __set__(self, instance, newValue):
-        if isinstance(newValue, Variable):
-            newValue = newValue.value
-
-        self.__value = newValue
-
-    @property
-    def value(self):
-        return self.__value
-
-    @property
-    def compute(self):
-        return self.__compute
-
-    @property
-    def method(self):
-        return self.__method
-
-    def __add__(self, other):
-        if isinstance(other, Variable):
-            other = other.value
-
-        self.__value = self.__value + other
-        return self
-
-    def __sub__(self, other):
-        if isinstance(other, Variable):
-            other = other.value
-
-        self.__value = self.__value - other
-        return self
-
-    def __mul__(self, other):
-        if isinstance(other, Variable):
-            other = other.value
-
-        self.__value = self.__value * other
-        return self
-
-    def __truediv__(self, other):
-        if isinstance(other, Variable):
-            other = other.value
-
-        self.__value = self.__value / other
-        return self
-
-    def __floordiv__(self, other):
-        if isinstance(other, Variable):
-            other = other.value
-
-        self.__value = self.__value // other
-        return self
-
-    def __eq__(self, other):
-        if isinstance(other, Variable):
-            other = other.value
-
-        return self.__value == other
-
-    def connect(self, mType):
-        def decorator(method):
-            if mType == "compute":
-                self.__compute = method
-            else:
-                self.__method = method
-
-            return method
-
-        return decorator
-
 class Binder():
     def __init__(self):
         self.__variables = []
         self.__methods = []
         self.__computes = []
+        self.__events = {}
 
     @property
-    def variables(self):
+    def variables(self) -> list:
         return self.__variables
 
     @property
-    def methods(self):
+    def methods(self) -> list:
         return self.__methods
 
     @property
-    def computes(self):
+    def computes(self) -> list:
         return self.__computes
 
+    @property
+    def events(self) -> dict:
+        return self.__events
+
     def variable(self, variable) -> bool:
         if not variable in self.__variables:
             self.__variables.append(variable)
@@ -128,15 +48,35 @@ class Binder():
 
         return decorator(func)
 
+    def event(self, eventType:str):
+        def decorator(func):
+            self.__events[eventType] = func.__name__
+
+            return func
+
+        return decorator
+
 class Model():
     binder = Binder()
     method = binder.method
     compute = binder.compute
+    event = binder.event
 
     def __init__(self):
-        for mname in [mname for mname in dir(self) if not mname in ("name", "variables")]:
-            if isinstance(eval("self.{}".format(mname)), Variable):
-                self.binder.variable(mname)
+        from copy import deepcopy
+
+        excludeList = ["binder", "session", "method", "compute", "event", "name", "variables", "sessions", "computes", "methods", "events"]
+        self.__mayVariables = [mname for mname in dir(self) if not mname in excludeList and not mname.startswith("__") and not mname.startswith("_Model__")]
+        self.__sessions = {}
+        for varName in self.__mayVariables:
+            if varName.startswith("session_"):
+                varNameVisible = varName[8:]
+                exec("self.{0} = deepcopy(self.{1})".format(varNameVisible, varName))
+
+                self.__mayVariables.remove(varName)
+                self.__mayVariables.append(varNameVisible)
+
+                self.__sessions[varNameVisible] = eval("self.{}".format(varNameVisible))
 
     @property
     def name(self) -> str:
@@ -145,11 +85,16 @@ class Model():
     @property
     def variables(self) -> dict:
         variableInfo = {}
-        for varName in self.binder.variables:
-            variableInfo[varName] = eval("self.{}".format(varName))
+        for varName in self.__mayVariables:
+            if not varName in self.binder.computes and not varName in self.binder.methods and not varName in self.binder.events.values():
+                variableInfo[varName] = eval("self.{}".format(varName))
 
         return variableInfo
 
+    @property
+    def sessions(self) -> dict:
+        return self.__sessions
+
     @property
     def computes(self) -> dict:
         computeInfo = {}
@@ -166,9 +111,16 @@ class Model():
 
         return methodInfo
 
+    @property
+    def events(self) -> dict:
+        eventInfo = {}
+        for eventType, eventName in self.binder.events.items():
+            eventInfo[eventType] = eval("self.{}".format(eventName))
+
+        return eventInfo
+
 class View():
     def __init__(self, name:str, prefix:str, resourceText:str, styleText:str, scriptText:str, templateText:str, modelTextInfo:dict):
-        from lxml.html import fromstring, tostring
         from .static import baseView, baseComponent
 
         self.__name = name
@@ -188,15 +140,15 @@ class View():
         ).replace(
             "{$viewBody}", templateText
         )
-        if self.__prefix == "view":
-            for line in self.__renderedText.split("\n"):
-                if line.strip().startswith("<component ") and "name" in line:
-                    componentName = line[11:-1].split("=")[1][1:-1]
+        # if self.__prefix == "view":
+        #     for line in self.__renderedText.split("\n"):
+        #         if line.strip().startswith("<component ") and "name" in line:
+        #             componentName = line[11:-1].split("=")[1][1:-1]
 
-                    self.__renderedText = self.__renderedText.replace(
-                        line,
-                        '<div style="width:100%;height:100%;"><object type="text/html" data="/components/{}" style="overflow:hidden;"></object></div>'.format(componentName)
-                    )
+        #             self.__renderedText = self.__renderedText.replace(
+        #                 line,
+        #                 '<div style="width:100%;height:100%;"><object type="text/html" data="/components/{}" style="overflow:hidden;width:100%;height:100%;"></object></div>'.format(componentName)
+        #             )
 
         self.__models = {}
         for modelName, modelText in modelTextInfo.items():
