@@ -36,18 +36,25 @@ class Server():
                         elif self.__get_view_type(res["name"]) == "component":
                             self.__appSession[res["id"]][res["name"]] = deepcopy(self.__components[res["name"]])
 
+                        for model in self.__appSession[res["id"]][res["name"]].models.values():
+                            for varName, var in model.sessions.items():
+                                self.__dataSession[res["id"]][varName] = var
+
+                        send_data_set = {
+                            modelName: {
+                                vName: var
+                                for vName, var in model.variables.items()
+                            }
+                            for modelName, model in self.__appSession[res["id"]][res["name"]].models.items()
+                        }
+                        send_data_set["session"] = self.__dataSession[res["id"]]
+
                         await self.__send_ws(
                             {
                                 "job": "init",
                                 "state": "success",
                                 "id": res["id"],
-                                "data": {
-                                    modelName: {
-                                        vName: var.value
-                                        for vName, var in model.variables.items()
-                                    }
-                                    for modelName, model in self.__appSession[res["id"]][res["name"]].models.items()
-                                },
+                                "data": send_data_set,
                                 "computes": {
                                     modelName: list(model.computes.keys())
                                     for modelName, model in self.__appSession[res["id"]][res["name"]].models.items()
@@ -89,6 +96,12 @@ class Server():
                                         elif res["job"] == "method":
                                             model.methods[res["method"]](self.__dataSession[res["id"]])
 
+                                    update_data = {
+                                        vName: var
+                                        for vName, var in model.variables.items()
+                                    }
+                                    update_data["session"] = self.__dataSession[res["id"]]
+
                                     await self.__send_ws(
                                         {
                                             "job": "update",
@@ -97,10 +110,7 @@ class Server():
                                             "id": res["id"],
                                             "view": res["view"],
                                             "model": model.name,
-                                            "vars": {
-                                                vName: var.value
-                                                for vName, var in model.variables.items()
-                                            }
+                                            "vars": update_data
                                         }
                                     )
                 else:
@@ -148,12 +158,18 @@ class Server():
         with open(pvFile, "r", encoding = "utf-8") as pvr:
             pvt = pvr.read()
 
+            prefixLine = pvt.split("\n")[0]
+            if prefixLine.startswith("!prefix"):
+                prefix = prefixLine[8:]
+            else:
+                prefix = "view"
+
             pvInfo = {
                 "resource": "",
                 "style": "",
                 "template": "",
                 "script": "",
-                "model": []
+                "model": {}
             }
             for key in pvInfo.keys():
                 try:
@@ -171,9 +187,18 @@ class Server():
                             for line in lines
                         ]
 
-                        if key == "model":
-                            modelBlocks = {}
+                        if key == "template":
+                            if prefix == "view":
+                                for idx in range(len(blockStripLines)):
+                                    line = blockStripLines[idx]
+                                    if line.strip().startswith("<component ") and "name" in line:
+                                        componentName = line[11:-2].split("=")[1].strip()[1:-1]
+                                        tabSpace = line.replace(line.strip(), "")
 
+                                        blockStripLines[idx] = tabSpace + '<object type="text/html" data="/components/{}" style="overflow:hidden;width:100%;height:100%;"></object>'.format(componentName)
+
+                            pvInfo[key] = "\n".join(blockStripLines)
+                        elif key == "model":
                             lineNums = []
                             for idx in range(len(blockStripLines)):
                                 line = blockStripLines[idx]
@@ -197,31 +222,24 @@ class Server():
 
                                 for mlIdx in range(1, len(modelLines)):
                                     line = modelLines[mlIdx]
-                                    if line.strip().startswith("def ") or line.strip().startswith("@"):
-                                        break
-
-                                    if not line == "":
-                                        lineSplit = [item for item in line.split("=")]
-                                        modelLines[mlIdx] = "{0} = Variable({1})".format(lineSplit[0], lineSplit[1].strip())
+                                    if ":session" in line:
+                                        varName = line.split(":session")[0].strip()
+                                        modelLines[mlIdx] = line.replace(
+                                            varName + ":session",
+                                            "session_" + varName
+                                        )
 
                                 insertSpace = modelLines[1].replace(modelLines[1].strip(), "")
                                 modelLines.insert(1, insertSpace + "compute = binder.compute")
                                 modelLines.insert(1, insertSpace + "method = binder.method")
                                 modelLines.insert(1, insertSpace + "binder = Binder()")
 
-                                modelBlocks[modelLines[0][6:-8]] = "\n".join(modelLines)
-
-                            pvInfo[key] = modelBlocks
+                                pvInfo[key][modelLines[0][6:-8]] = "\n".join(modelLines)
                         else:
                             pvInfo[key] = "\n".join(blockStripLines)
 
             pvInfo["name"] = os.path.splitext(os.path.basename(pvFile))[0]
-
-            prefixLine = pvt.split("\n")[0]
-            if prefixLine.startswith("!prefix"):
-                pvInfo["prefix"] = prefixLine[8:]
-            else:
-                pvInfo["prefix"] = "view"
+            pvInfo["prefix"] = prefix
 
             return pvInfo
 
@@ -234,7 +252,10 @@ class Server():
     async def __send_ws(self, sendInfo:dict):
         import json
 
-        await self.__websocket.send(json.dumps(sendInfo))
+        try:
+            await self.__websocket.send(json.dumps(sendInfo))
+        except:
+            print(sendInfo)
 
     async def __get_ws(self) -> dict:
         import json
